from ._api_specs.v7_2_0 import v7_2_0
from ._api_specs.v7_2_6 import v7_2_6
from ._api_specs.v8_0_0 import v8_0_0
from ._api_specs.v9_1_0 import v9_1_0
from ._api_specs.v9_2_0 import v9_2_0
from ._api_specs.v10_0_0 import v10_0_0
from ._api_specs.v10_1_2 import v10_1_2
from ._api_specs.v10_5_0 import v10_5_0

apiSpec = {
    "7.2.0": v7_2_0,
    "7.2.6": v7_2_6,
    "8.0.0": v8_0_0,
    "9.1.0": v9_1_0,
    "9.2.0": v9_2_0,
    "10.0.0": v10_0_0,
    "10.1.2": v10_1_2,
    "10.5.0": v10_5_0,
}
